@@ -1,11 +1,13 @@
-use crate::manifest::description::{Layer, PackFlow};
 use rill_protocol::flow::core::Flow;
 use rill_protocol::io::provider::StreamType;
+use rrpack_basis::manifest::description::{Layer, PackFlow};
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct InputSpec {
     pub label: String,
+    pub wide: bool,
+    pub password: bool,
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
