@@ -1,9 +1,8 @@
 use super::state::*;
-use crate::auto_path::AutoPath;
-use crate::manifest::BindedTracer;
 use derive_more::{Deref, DerefMut};
 use rill_derive::TracerOpts;
 use rill_protocol::flow::core::FlowMode;
+use rrpack_basis::{AutoPath, BindedTracer};
 
 #[derive(TracerOpts, Clone, Default)]
 pub struct SliderOpts {
@@ -11,6 +10,7 @@ pub struct SliderOpts {
     pub min: Option<f64>,
     pub max: Option<f64>,
     pub step: Option<f64>,
+    pub instant: Option<bool>,
 }
 
 impl From<SliderOpts> for SliderSpec {
@@ -20,6 +20,7 @@ impl From<SliderOpts> for SliderSpec {
             min: opts.min.unwrap_or(1.0),
             max: opts.max.unwrap_or(100.0),
             step: opts.step.unwrap_or(1.0),
+            instant: opts.instant.unwrap_or_default(),
         }
     }
 }
