@@ -1,11 +1,10 @@
 use super::state::*;
-use crate::auto_path::AutoPath;
-use crate::manifest::BindedTracer;
 use derive_more::{Deref, DerefMut};
 use rill_derive::TracerOpts;
 use rill_protocol::flow::core::FlowMode;
+use rrpack_basis::{AutoPath, BindedTracer};
 
-#[derive(TracerOpts, Default)]
+#[derive(TracerOpts, Clone, Default)]
 pub struct AlertOpts {}
 
 impl From<AlertOpts> for AlertSpec {
