@@ -1,9 +1,8 @@
 use super::state::*;
-use crate::auto_path::AutoPath;
-use crate::manifest::BindedTracer;
 use derive_more::{Deref, DerefMut};
 use rill_derive::TracerOpts;
 use rill_protocol::flow::core::FlowMode;
+use rrpack_basis::{AutoPath, BindedTracer};
 
 #[derive(TracerOpts, Clone, Default)]
 pub struct LiveTextOpts {}
